@@ -29,53 +29,86 @@ setMethod("getVersion", "Dataclass",
            function(object) object@version)### new v.1.8
 
 setMethod("Dataclass","DataframeorSeqDataFrames", function(Data, filename = NULL, name = "Data-Set"){ 
- runs0 <- runs(Data)
+ if(!is(Data,"SeqDataFrames"))
+    Data <- SeqDataFrames(Data)
+ runs0 <-  runs(Data) 
  obsDim0 <- obsDim(Data)
- dimnames0 <- obsDimnames(Data)
- rnames <- names(Data)
- dnames <- obsDimnames(Data)
  samplesize0 <- samplesize(Data)
- new("Dataclass", filename = filename, Data = Data0, runs = runs0, 
+ new("Dataclass", filename = filename, Data = Data, runs = runs0, 
      obsDim = obsDim0, samplesize = samplesize0, name = name)
 })
 
 setMethod("Dataclass","ArrayorNULLorVector", function(Data, filename = NULL, name = "Data-Set") 
 {if(is.null(Data))
     stop("generating an object of class \"Dataclasss\" requires data of type \"array\" or \"vector\"")
-
+ 
  runs0 <- 1
  obsDim0 <- 1
+ samplesize0 <- length(Data)
  dimnames0 <- NULL
  rnames <- NULL
  dnames <- NULL
  snames <- NULL
- if(is(Data,"array") & !is.na(dim(Data)[3]))
-    { runs0 <- dim(Data)[3]   
-      if(!is.null(dimnames(Data))) 
-          rnames <- dimnames(Data)[[3]]
-    } 
- if(!is.null(dim(Data)))
-    { obsDim0 <- dim(Data)[2]   
-      samplesize0 <- dim(Data)[1] 
-      if(!is.null(dimnames(Data))) 
-          {dnames <- dimnames(Data)[[2]]
-           snames <- dimnames(Data)[[1]]
-           dimnames0 <- list(snames, dnames, rnames)
-      } else {
-      samplesize0 <- length(Data)
-      if(!is.null(names(Data)))  
-          {snames <- names(Data)
-           dimnames0 <- list(snames, dnames, rnames)
-           }
-      }
-    }
-      
+ if(!is.null(names(Data)))  
+    {snames <- names(Data)
+     dimnames0 <- list(snames, dnames, rnames)
+     }
  Data0 <- array(data = Data, dim = c(samplesize0,obsDim0,runs0),
                 dimnames = dimnames0)       
  new("Dataclass", filename = filename, Data = Data0, runs = runs0, 
      obsDim = obsDim0, samplesize = samplesize0, name = name)
 })
 
+setMethod("Dataclass","matrix", function(Data, filename = NULL, name = "Data-Set") 
+{if(is.null(Data))
+    stop("generating an object of class \"Dataclasss\" requires data of type \"array\" or \"vector\"")
+ 
+ runs0 <- 1
+ rnames <- NULL
+ dimnames0 <- NULL
+ obsDim0 <- ncol(Data)   
+ samplesize0 <- nrow(Data)
+ if(!is.null(dimnames(Data))) 
+    {dnames <- colnames(Data)
+     snames <- rownames(Data)
+     dimnames0 <- list(snames, dnames, rnames)
+ }    
+ Data0 <- array(data = Data, dim = c(samplesize0,obsDim0,runs0),
+                dimnames = dimnames0)       
+ new("Dataclass", filename = filename, Data = Data0, runs = runs0, 
+     obsDim = obsDim0, samplesize = samplesize0, name = name)      
+})
+
+setMethod("Dataclass","array", function(Data, filename = NULL, name = "Data-Set") 
+{if(is.null(Data))
+    stop("generating an object of class \"Dataclasss\" requires data of type \"array\" or \"vector\"")
+ if(length(dim(Data))>3) 
+    stop("generating an object of class \"Dataclasss\" requires data of type \"array\" in atmost 3 dimensions")
+
+ samplesize0 <- dim(Data)[1] 
+ snames  <- dimnames(Data)[1]
+
+ if(length(dim(Data))==1) {
+    obsDim0 <- 1 
+    dnames  <- NULL
+ }else{
+    obsDim0 <- dim(Data)[2] 
+    dnames  <- dimnames(Data)[2]
+ }
+ if(length(dim(Data))<=2) {
+    runs0  <- 1 
+    rnames <- NULL
+ }else{
+    runs0  <- dim(Data)[3] 
+    rnames <- dimnames(Data)[3]
+ }
+ dimnames0 <- list(snames, dnames, rnames)
+ Data0 <- array(data = Data, dim = c(samplesize0,obsDim0,runs0),
+                dimnames = dimnames0)       
+ new("Dataclass", filename = filename, Data = Data0, runs = runs0, 
+     obsDim = obsDim0, samplesize = samplesize0, name = name)      
+})
+
  
 
 
